==> tutti-ui-swing-1.1-sources.jar: fr/ifremer/tutti/ui/swing/util/editor/TuttiComputedOrNotDataEditorHandler.java <==

package fr.ifremer.tutti.ui.swing.util.editor;

/*
 * #%L
 * Tutti :: UI
 * $Id: TuttiComputedOrNotDataEditorHandler.java 632 2013-03-15 11:13:13Z kmorin $
 * $HeadURL: http://svn.forge.codelutin.com/svn/tutti/tags/tutti-1.1/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/util/editor/TuttiComputedOrNotDataEditorHandler.java $
 * %%
 * Copyright (C) 2012 - 2013 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import fr.ifremer.tutti.ui.swing.util.TuttiComputedOrNotData;
import fr.ifremer.tutti.ui.swing.util.TuttiUI;
import fr.ifremer.tutti.ui.swing.util.TuttiUIUtil;
import jaxx.runtime.JAXXUtil;
import jaxx.runtime.swing.editor.NumberEditorHandler;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import javax.swing.JTextField;
import java.awt.Color;
import java.awt.event.FocusEvent;
import java.awt.event.FocusListener;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.text.DecimalFormat;
import org.apache.commons.lang3.StringUtils;

/**
 * @author kmorin <kmorin@codelutin.com>
 * @since 1.0
 */
public class TuttiComputedOrNotDataEditorHandler extends NumberEditorHandler {

    private static final Log log = LogFactory.getLog(TuttiComputedOrNotDataEditorHandler.class);

    protected Integer decimalNumber;

    public TuttiComputedOrNotDataEditorHandler(TuttiComputedOrNotDataEditor ui) {
        super(ui);
    }

    @Override
    public void init() {
        final PropertyChangeListener l = new PropertyChangeListener() {

            public void propertyChange(PropertyChangeEvent evt) {
                setComputedTextIfNullModel();
            }
        };

        TuttiComputedOrNotData bean = (TuttiComputedOrNotData) editor.getBean();
        if (bean != null) {
            bean.addPropertyChangeListener(l);
        }
        editor.addPropertyChangeListener(TuttiComputedOrNotDataEditor.PROPERTY_BEAN, new PropertyChangeListener() {

            public void propertyChange(PropertyChangeEvent evt) {

                TuttiComputedOrNotData bean = (TuttiComputedOrNotData) evt.getOldValue();
                if (bean != null) {
                    bean.removePropertyChangeListener(TuttiComputedOrNotData.PROPERTY_COMPUTED_DATA, l);
                }

                bean = (TuttiComputedOrNotData) evt.getNewValue();
                if (bean != null) {
                    bean.addPropertyChangeListener(TuttiComputedOrNotData.PROPERTY_COMPUTED_DATA, l);
                }
            }
        });

        editor.addPropertyChangeListener(TuttiComputedOrNotDataEditor.PROPERTY_MODEL, l);

        editor.getTextField().addFocusListener(new FocusListener() {

            public void focusGained(FocusEvent e) {
                JTextField tf = editor.getTextField();
                tf.setFont(TuttiUI.TEXTFIELD_NORMAL_FONT);
                tf.setForeground(Color.BLACK);
                if (editor.getModel() == null) {
                    tf.setText("");
                }
            }

            public void focusLost(FocusEvent e) {
                setComputedTextIfNullModel();
            }
        });

        editor.addPropertyChangeListener(TuttiComputedOrNotDataEditor.PROPERTY_DECIMAL_NUMBER,
                                         new PropertyChangeListener() {

                                             public void propertyChange(PropertyChangeEvent evt) {
                                                 decimalNumber = (Integer) evt.getNewValue();
                                             }
                                         });

        decimalNumber = ((TuttiComputedOrNotDataEditor) editor).getDecimalNumber();

        super.init();

    }

    protected void setComputedTextIfNullModel() {
        TuttiComputedOrNotData bean = (TuttiComputedOrNotData) editor.getBean();
        JTextField tf = editor.getTextField();
        if (bean != null && editor.getModel() == null) {
            tf.setFont(TuttiUI.TEXTFIELD_COMPUTED_FONT);
            tf.setForeground(((TuttiComputedOrNotDataEditor) editor).getComputedDataColor());

            String modelText;
            Number computedData = bean.getComputedData();
            if (editor.isUseFloat()
                && decimalNumber != null && computedData != null) {
                DecimalFormat decimalFormat = TuttiUIUtil.getDecimalFormat(1, decimalNumber);
                modelText = decimalFormat.format(computedData);
            } else {
                modelText = JAXXUtil.getStringValue(computedData);
            }
            tf.setText(modelText);

        } else {
            tf.setFont(TuttiUI.TEXTFIELD_NORMAL_FONT);
            tf.setForeground(Color.BLACK);
        }
    }

}

==> tutti-ui-swing-1.1.1-sources.jar: fr/ifremer/tutti/ui/swing/util/editor/TuttiComputedOrNotDataEditorHandler.java <==

package fr.ifremer.tutti.ui.swing.util.editor;

/*
 * #%L
 * Tutti :: UI
 * $Id: TuttiComputedOrNotDataEditorHandler.java 632 2013-03-15 11:13:13Z kmorin $
 * $HeadURL: http://svn.forge.codelutin.com/svn/tutti/tags/tutti-1.1.1/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/util/editor/TuttiComputedOrNotDataEditorHandler.java $
 * %%
 * Copyright (C) 2012 - 2013 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import fr.ifremer.tutti.ui.swing.util.TuttiComputedOrNotData;
import fr.ifremer.tutti.ui.swing.util.TuttiUI;
import fr.ifremer.tutti.ui.swing.util.TuttiUIUtil;
import jaxx.runtime.JAXXUtil;
import jaxx.runtime.swing.editor.NumberEditorHandler;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import javax.swing.JTextField;
import java.awt.Color;
import java.awt.event.FocusEvent;
import java.awt.event.FocusListener;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.text.DecimalFormat;
import org.apache.commons.lang3.StringUtils;

/**
 * @author kmorin <kmorin@codelutin.com>
 * @since 1.0
 */
public class TuttiComputedOrNotDataEditorHandler extends NumberEditorHandler {

    private static final Log log = LogFactory.getLog(TuttiComputedOrNotDataEditorHandler.class);

    protected Integer decimalNumber;

    public TuttiComputedOrNotDataEditorHandler(TuttiComputedOrNotDataEditor ui) {
        super(ui);
    }

    @Override
    public void init() {
        final PropertyChangeListener l = new PropertyChangeListener() {

            public void propertyChange(PropertyChangeEvent evt) {
                setComputedTextIfNullModel();
            }
        };

        TuttiComputedOrNotData bean = (TuttiComputedOrNotData) editor.getBean();
        if (bean != null) {
            bean.addPropertyChangeListener(l);
        }
        editor.addPropertyChangeListener(TuttiComputedOrNotDataEditor.PROPERTY_BEAN, new PropertyChangeListener() {

            public void propertyChange(PropertyChangeEvent evt) {

                TuttiComputedOrNotData bean = (TuttiComputedOrNotData) evt.getOldValue();
                if (bean != null) {
                    bean.removePropertyChangeListener(TuttiComputedOrNotData.PROPERTY_COMPUTED_DATA, l);
                }

                bean = (TuttiComputedOrNotData) evt.getNewValue();
                if (bean != null) {
                    bean.addPropertyChangeListener(TuttiComputedOrNotData.PROPERTY_COMPUTED_DATA, l);
                }
            }
        });

        editor.addPropertyChangeListener(TuttiComputedOrNotDataEditor.PROPERTY_MODEL, l);

        editor.getTextField().addFocusListener(new FocusListener() {

            public void focusGained(FocusEvent e) {
                JTextField tf = editor.getTextField();
                tf.setFont(TuttiUI.TEXTFIELD_NORMAL_FONT);
                tf.setForeground(Color.BLACK);
                if (editor.getModel() == null) {
                    tf.setText("");
                }
            }

            public void focusLost(FocusEvent e) {
                setComputedTextIfNullModel();
            }
        });

        editor.addPropertyChangeListener(TuttiComputedOrNotDataEditor.PROPERTY_DECIMAL_NUMBER,
                                         new PropertyChangeListener() {

                                             public void propertyChange(PropertyChangeEvent evt) {
                                                 decimalNumber = (Integer) evt.getNewValue();
                                             }
                                         });

        decimalNumber = ((TuttiComputedOrNotDataEditor) editor).getDecimalNumber();

        super.init();

    }

    protected void setComputedTextIfNullModel() {
        TuttiComputedOrNotData bean = (TuttiComputedOrNotData) editor.getBean();
        JTextField tf = editor.getTextField();
        if (bean != null && editor.getModel() == null) {
            tf.setFont(TuttiUI.TEXTFIELD_COMPUTED_FONT);
            tf.setForeground(((TuttiComputedOrNotDataEditor) editor).getComputedDataColor());

            String modelText;
            Number computedData = bean.getComputedData();
            if (editor.isUseFloat()
                && decimalNumber != null && computedData != null) {
                DecimalFormat decimalFormat = TuttiUIUtil.getDecimalFormat(1, decimalNumber);
                modelText = decimalFormat.format(computedData);
            } else {
                modelText = JAXXUtil.getStringValue(computedData);
            }
            tf.setText(modelText);

        } else {
            tf.setFont(TuttiUI.TEXTFIELD_NORMAL_FONT);
            tf.setForeground(Color.BLACK);
        }
    }

}
